<?php

/**
 * @file
 * Cron functions for the Admissions module of the Cura Childcare Suite.
 */

/**
 * Cron scheduler.
 */
function cura_admissions_cron_scheduler() {

  // Run these on the first day of the month.
  if (date('j', time()) == 1) {
    cura_admissions_send_waiting_list_emails();
    watchdog('cura_admissions', 'Cron ran on the first day of the month.');
  }

  return TRUE;
}

/**
 * Sends email notifications to people on the waiting list.
 */
function cura_admissions_send_waiting_list_emails() {

  // Get the relevant settings.
  $settings = cura_get_settings('general');

  // Get the children on the waiting list.
  $child_nids = cura_get_children('nids', array('W'));
  $children = entity_load('node', $child_nids);

  // Send waiting list email to each child.
  $count = 0;
  foreach ($children as $child) {
    if (cura_admissions_send_waiting_list_email($child, $settings)) {
      $count++;
    }
  }
  watchdog('cura', 'Sent %c email notifications to waiting list.', array('%c' => $count));
}

/**
 * Sends a waiting list email to the account owner.
 */
function cura_admissions_send_waiting_list_email($child, $settings = NULL) {

  $module = 'cura_admissions';
  $key = 'waiting_list';
  $language = language_default();
  $send = TRUE;

  // Get the relevant settings.
  if (empty($settings)) $settings = cura_get_settings('general');
  $email_settings = cura_get_settings('notification', 'email', $key);
  $email_settings = $email_settings['notification']['email'][$key];

  // Check that email notifications have been enabled.
  if (!$settings['general']['notification']['email']['enabled']) {
    watchdog($module, 'Email notifications are not enabled!');
    return;
  }
  if (!$email_settings['enabled']) {
    watchdog($module, 'Waiting list email notifications are not enabled!');
    return;
  }

  $from = $email_settings['from'];
  $cw = entity_metadata_wrapper('node', $child);
  if (!$start = cura_get_child_start_date($child->nid)) {
    $start = REQUEST_TIME;
  }
  $session_plans = cura_session_plan_load(NULL, NULL, array($child->nid));
  module_load_include('inc', 'cura', 'cura.sessions');
  $session_plan = cura_display_session_plan($child, $start);
  // Set the variables.
  $vars = array(
    '@site_url' => file_create_url(''),
    '@org_name' => $settings['general']['org']['general']['org_name'],
    '@org_name_short' => $settings['general']['org']['general']['org_name_short'],
    '@child_firstname' => $cw->cura_firstname->value(),
    '@child_lastname' => $cw->cura_lastname->value(),
    '@child_start_date' => date('l, j F Y', $cw->field_child_start_date->value()),
    '@child_wl_position' => $cw->field_child_wl_position->raw(),
    '!session_plan' => drupal_render($session_plan),
    '@parent_firstname' => $cw->field_account_id->field_account_owner->field_firstname->value(),
    '@parent_lastname' => $cw->field_account_id->field_account_owner->field_lastname->value(),
    '@account_number' => $cw->field_account_id->field_account_number->raw(),
    '!email_signature' => cura_email_signature('Admissions'),
  );
  $to = $vars['@parent_firstname'] . ' ' . $vars['@parent_lastname'] . ' <';
  $to .= $cw->field_account_id->field_account_owner->field_email->value() . '>';
  // $to = 'Administrator <' . variable_get('site_mail', ini_get('sendmail_from')) . '>'; // ** TESTING **
  $params = array(
    'headers' => array('cc' => $email_settings['cc']),
    'subject' => filter_xss($vars['@org_name_short'] . ' waiting list - ' . $vars['@child_firstname'] . ' ' . $vars['@child_lastname']),
    'body' => array(
      t($email_settings['body'], $vars),
      t($settings['general']['org']['general']['footer'], $vars),
    ),
  );

  // Send the email.
  $result = cura_send_email($module, $key, $to, $language, $params, $from, $send);
  if ($result['result'] == TRUE) {
    watchdog($module, 'Sent waiting list email to @to.', array('@to' => $to));
  }
  else {
    watchdog($module, 'Could not send waiting list email to @to.', array('@to' => $to), WATCHDOG_ERROR);
  }

  return $result['result'];
}

